@@ -23,6 +23,7 @@ use libc::c_char;
 use std::ffi::CStr;
 
 /// Panic if a pointer is null.
+#[inline]
 fn panic_if_null<T>(pointer: *const T) {
     if pointer.is_null() {
         unreachable!("A null pointer was passed to the library, something is wrong in the C or C++ code");
@@ -30,18 +31,21 @@ fn panic_if_null<T>(pointer: *const T) {
 }
 
 /// Convert type to raw pointer.
+#[inline]
 pub fn raw<T>(data: T) -> *mut T {
-    let pointer = Box::into_raw(Box::new(data));
-    pointer
+    Box::into_raw(Box::new(data))
 }
 
 /// Free pointer to type.
 /// 
-/// **WARNING: never call it twice.**
+/// # Crashes
+/// 
+/// **WARNING: never call it twice. That could produce a HEAP error that produce a crash.**
+#[inline]
 pub fn free<T>(pointer: *mut T) {
     if pointer.is_null() {
         #[cfg(debug_assertions)]
-        unreachable!("internal error: entered unreachable code");
+        unreachable!("A null pointer was passed to the library, something is wrong in the C or C++ code");
         #[cfg(not(debug_assertions))]
         return;
     }
@@ -51,29 +55,37 @@ pub fn free<T>(pointer: *mut T) {
 
 /// Own back from a raw pointer.
 /// 
-/// **WARNING: never call it twice.**
+/// # Crashes
+/// 
+/// **WARNING: never call it twice. That could produce a HEAP error that produce a crash.**
+#[inline]
 pub fn own_back<T>(pointer: *mut T) -> T {
     panic_if_null(pointer);
-    let boxed = unsafe {
-        Box::from_raw(pointer)
-    };
+    let boxed = unsafe { Box::from_raw(pointer) };
     *boxed
 }
 
 /// Convert raw pointer to type to type reference.
+#[inline]
 pub fn object<'a, T>(pointer: *const T) -> &'a T {
     panic_if_null(pointer);
     unsafe { &*pointer }
 }
 
 /// Convert raw pointer to type into type mutable reference.
+#[inline]
 pub fn mut_object<'a, T>(pointer: *mut T) -> &'a mut T {
     panic_if_null(pointer);
     unsafe { &mut *pointer }
 }
 
 /// Reference to a C string.
+/// 
+/// # Panics
+/// 
+/// This could panic if the C string is not a valid UTF-8 string.
 #[cfg(feature = "libc")]
+#[inline]
 pub fn ref_str<'a>(string: *const c_char) -> &'a str {
     panic_if_null(string);
     let string = unsafe { CStr::from_ptr(string) };
